{% load my my_amp %}

<a target="_blank" href="{{ mailto_url|safe }}">
    {% amp_img %}
        <img class="s-icon x2" src="{{ icons.email|ico:page.theme }}"
             alt="Icon Email"/>
    {% endamp_img %}
</a>
