{% load my my_amp %}

<a target="_blank" href="{{ tweet_url }}">
    {% amp_img %}
        <img class="s-icon x2" src="{{ icons.twitter|ico:page.theme }}"
             alt="Icon Twitter"/>
    {% endamp_img %}
</a>
